@@ -1,9 +1,9 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # SoundConverter - GNOME application for converting between audio formats.
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2020 Gautier Portet
+# Copyright 2005-2025 Gautier Portet
+# Copyright 2020-2025 Sezanzeb
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,16 +28,18 @@ notification = _notification_dummy
 
 try:
     import gi
-    gi.require_version('Notify', '0.7')
+
+    gi.require_version("Notify", "0.7")
     from gi.repository import Notify
 
     def _notification(message):
         try:
-            Notify.Notification('SoundConverter', message).show()
-        except Exception:
+            Notify.Notification("SoundConverter", message).show()
+        except Exception as e:
+            print("Error sending notification:", e)
             pass
 
-    if Notify.init('Basics'):
+    if Notify.init("Basics"):
         notification = _notification
 
 except (ImportError, ValueError):
